==> create-fly-1.21.8-6.0.8-1-sources.jar: com/zurrtum/create/client/mixin/PlayerEntityRendererMixin.java <==
package com.zurrtum.create.client.mixin;

import com.zurrtum.create.client.AllExtensions;
import com.zurrtum.create.client.content.equipment.armor.CardboardRenderState;
import com.zurrtum.create.client.foundation.render.SkyhookRenderState;
import net.minecraft.class_10055;
import net.minecraft.class_1007;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1792;
import net.minecraft.class_572.class_573;
import net.minecraft.class_742;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1007.class)
public class PlayerEntityRendererMixin {
    @Inject(method = "getArmPose(Lnet/minecraft/client/network/AbstractClientPlayerEntity;Lnet/minecraft/util/Arm;)Lnet/minecraft/client/render/entity/model/BipedEntityModel$ArmPose;", at = @At(value = "HEAD"), cancellable = true)
    private static void getArmPose(class_742 player, class_1306 arm, CallbackInfoReturnable<class_573> cir) {
        class_1268 hand = player.method_6068() == arm ? class_1268.field_5808 : class_1268.field_5810;
        class_1792 item = player.method_5998(hand).method_7909();
        class_573 pose = AllExtensions.ARM_POSE.get(item);
        if (pose != null) {
            cir.setReturnValue(pose);
        }
    }

    @Inject(method = "updateRenderState(Lnet/minecraft/client/network/AbstractClientPlayerEntity;Lnet/minecraft/client/render/entity/state/PlayerEntityRenderState;F)V", at = @At("TAIL"))
    private void updateRenderState(class_742 player, class_10055 state, float tickProgress, CallbackInfo ci) {
        ((CardboardRenderState) state).create$update(player, tickProgress);
        SkyhookRenderState skyhookRenderState = (SkyhookRenderState) state;
        skyhookRenderState.create$setUuid(player.method_5667());
        skyhookRenderState.create$setMainStack(player.method_6047());
    }
}

==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/mixin/PlayerEntityRendererMixin.java <==
package com.zurrtum.create.client.mixin;

import com.zurrtum.create.client.AllExtensions;
import com.zurrtum.create.client.content.equipment.armor.CardboardRenderState;
import com.zurrtum.create.client.foundation.render.SkyhookRenderState;
import net.minecraft.class_10055;
import net.minecraft.class_1007;
import net.minecraft.class_11890;
import net.minecraft.class_11901;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1792;
import net.minecraft.class_572.class_573;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1007.class)
public class PlayerEntityRendererMixin<AvatarlikeEntity extends class_11890 & class_11901> {
    @Inject(method = "getArmPose(Lnet/minecraft/entity/PlayerLikeEntity;Lnet/minecraft/util/Arm;)Lnet/minecraft/client/render/entity/model/BipedEntityModel$ArmPose;", at = @At(value = "HEAD"), cancellable = true)
    private static void getArmPose(class_11890 player, class_1306 arm, CallbackInfoReturnable<class_573> cir) {
        class_1268 hand = player.method_6068() == arm ? class_1268.field_5808 : class_1268.field_5810;
        class_1792 item = player.method_5998(hand).method_7909();
        class_573 pose = AllExtensions.ARM_POSE.get(item);
        if (pose != null) {
            cir.setReturnValue(pose);
        }
    }

    @Inject(method = "updateRenderState(Lnet/minecraft/entity/PlayerLikeEntity;Lnet/minecraft/client/render/entity/state/PlayerEntityRenderState;F)V", at = @At("TAIL"))
    private void updateRenderState(AvatarlikeEntity player, class_10055 state, float tickProgress, CallbackInfo ci) {
        ((CardboardRenderState) state).create$update(player, tickProgress);
        SkyhookRenderState skyhookRenderState = (SkyhookRenderState) state;
        skyhookRenderState.create$setUuid(player.method_5667());
        skyhookRenderState.create$setMainStack(player.method_6047());
    }
}
